@@ -4,14 +4,14 @@ use Moose;
 use 5.10.0;
 extends 'Net::OpenVPN::ProxyManager';
 
-our $VERSION = '0.011';
+our $VERSION = '0.02';
 
 has hma_server_list => (is => 'rw', isa => 'ArrayRef', builder => '_get_server_list');
 has hma_config 		=> (is => 'rw', isa => 'Str', builder => '_get_hma_config');
 
 =head1 NAME
 
-OpenVPN::ProxyManager::HMA - connect to HideMyAss.com (HMA) proxy servers using OpenVPN.
+Net::OpenVPN::ProxyManager::HMA - connect to HideMyAss.com (HMA) proxy servers using OpenVPN.
 
 =head1 SYNOPSIS
 
@@ -29,12 +29,12 @@ HMA proxy servers by automatically downloading the latest list of available HMA
 configuration (this is done at construction of the object).
 
 
-=head1 Dependencies (non-Perl)
+=head1 DEPENDENCIES
 
 To login to the HMA proxy servers, you will need to have an active account with HMA 
 (http://hidemyass.com). I am not affiliated with HMA other than as a customer.
 
-See L<Net::OpenVPN::ProxyManager> for other dependencies.
+See L<Net::OpenVPN::ProxyManager::HMA> for other dependencies.
 
 =cut
 
@@ -67,6 +67,9 @@ sub _parse_server_list_string {
 	}
 	return $server_list_arrayhash;
 }
+
+=head1 METHODS
+
 =head2 get_servers
 
 This method returns an arrayhash of HMA servers available (the list is downloaded upon 
@@ -173,3 +176,89 @@ sub hma_connect {
 
 no Moose;
 1;
+
+=head1 AUTHOR
+
+David Farrell, C<< <davidnmfarrell at gmail.com> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-net-openvpn-proxymanager-hma at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-OpenVPN-ProxyManager>.  I will be notified, and then you'll automatically be notified of 
+progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Net::OpenVPN::ProxyManager::HMA
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Net-OpenVPN-ProxyManager-HMA>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Net-OpenVPN-ProxyManager-HMA>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Net-OpenVPN-ProxyManager-HMA>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Net-OpenVPN-ProxyManager-HMA/>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2013 David Farrell.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified
+Versions is governed by this Artistic License. By using, modifying or
+distributing the Package, you accept this license. Do not use, modify,
+or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made
+by someone other than you, you are nevertheless required to ensure that
+your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service
+mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge
+patent license to make, have made, use, offer to sell, sell, import and
+otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by the
+Package. If you institute patent litigation (including a cross-claim or
+counterclaim) against any party alleging that the Package constitutes
+direct or contributory patent infringement, then this Artistic License
+to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
+AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
+THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
+YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
+CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
+EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+
+=cut
